.. _gwpy-external-nds2:

####
NDS2
####

.. image:: https://img.shields.io/conda/vn/conda-forge/python-nds2-client.svg
    :alt: python-nds2-client conda-forge version
    :target: https://anaconda.org/conda-forge/python-nds2-client
.. image:: https://img.shields.io/conda/pn/conda-forge/python-nds2-client.svg
    :alt: python-nds2-client conda-forge platforms
    :target: https://anaconda.org/conda-forge/python-nds2-client

Network Data Service (NDS) 2 is a TCP/IP protocol for retrieving data from
gravitational-wave detector archives.
The NDS2 Client is a C++ library that provides high-level bindings for Python
to allow users to securely connect to and retrieve data from NDS2 servers.

The NDS2 client bindings for Python can be installed using `Conda <https://conda.io>`__
(or `Mamba <https://mamba.readthedocs.io/en/stable/>`__) on any platform:

.. code-block:: shell
    :name: conda-install-python-nds2-client
    :caption: Install python-nds2-client with conda

    conda install -c conda-forge python-nds2-client
